@@ -17,10 +17,16 @@
 .lkdefaults <- new.env(parent=emptyenv());
 
 # Set the credentials used for all http or https requests
-# For now, just apiKey. TODO: Add email, password, baseUrl, folderPath, and maybe curlOptions & lkOptions
-labkey.setDefaults <- function(apiKey=NULL)
+# For now, just apiKey and baseUrl. TODO: Add email, password, folderPath, and maybe curlOptions & lkOptions
+labkey.setDefaults <- function(apiKey="", baseUrl="")
 {
-    .lkdefaults[["apiKey"]] = apiKey;
+    if (apiKey != "")
+        .lkdefaults[["apiKey"]] = apiKey;
+    if (baseUrl != "")
+        .lkdefaults[["baseUrl"]] = baseUrl;
+    # for backward compatibility, clear defaults if setDefaults() is called with NO arguments
+    if (apiKey == "" && baseUrl=="")
+      .lkdefaults <- new.env(parent=emptyenv());
 }
 
 ifApiKey <- function()
@@ -32,6 +38,15 @@ ifApiKey <- function()
     }
 }
 
+labkey.getBaseUrl <- function(baseUrl=NULL)
+{
+    if (!is.null(baseUrl) && baseUrl != "") {
+      return (baseUrl)
+    } else {
+        return (.lkdefaults[["baseUrl"]])
+    }
+}
+
 ## Executes an HTTP GET against the supplied URL, with standard handling for session, api key, status codes and error messages.
 labkey.get <- function(myurl)
 {
@@ -115,8 +130,11 @@ processResponse <- function(mydata, header, handle)
 {
     ## Error checking, decode data and return
     h <- parseHeader(header$value())
-    status <- getCurlInfo(handle)$response.code
     message <- h$statusMessage
+    status <- getCurlInfo(handle)$response.code
+    if (status == 0) {
+        status <- h$status
+    }
 
     if(status==500)
     {
@@ -140,4 +158,4 @@ processResponse <- function(mydata, header, handle)
     }
 
     mydata
-}
\ No newline at end of file
+}
